# [1.3.11](https://github.com/seriaati/yatta/compare/v1.3.10..v1.3.11) - 2024-12-03

## Bug Fixes

- Suppress weird pyright errors - ([b4a1781](https://github.com/seriaati/yatta/commit/b4a1781f74ba51981eff88c76638c3a150dfdc7b))

## Features

- Add Remembrance path type - ([6444c54](https://github.com/seriaati/yatta/commit/6444c549c41c45a2c74fff74e63f2a6945364204))

## Miscellaneous Chores

- **(deps)** lock file maintenance ([#67](https://github.com/seriaati/yatta/issues/67)) - ([f979ee1](https://github.com/seriaati/yatta/commit/f979ee19b2a1f738fdcda5ab0512a97c6ac02033))
- **(deps)** lock file maintenance ([#68](https://github.com/seriaati/yatta/issues/68)) - ([6d5cb2f](https://github.com/seriaati/yatta/commit/6d5cb2f820c75a4c6965d5bb034ae4243b9feeae))
- Fix ruff config - ([7c82ed4](https://github.com/seriaati/yatta/commit/7c82ed404af7d9caa47c2ba4f34c905c2eb2bcb3))
- Fix project name - ([6c29c78](https://github.com/seriaati/yatta/commit/6c29c78472f24b0e89924b89e5d2afccd32f06dc))
- Remove poetry lock file - ([5a72084](https://github.com/seriaati/yatta/commit/5a72084c0182e77d597916a630c428e67e63c0ad))
- Add python version specifier - ([434656b](https://github.com/seriaati/yatta/commit/434656beb6458a903a1ef9d5f7753fe89ff2c2b4))

## Style

- Format code - ([00b17cd](https://github.com/seriaati/yatta/commit/00b17cdd70ea57894d7a16ce823caa1d0c0c2121))

